#!/usr/bin/env python
# -*- coding: latin-1 -*-

# Script para Gimp en Python
# Realizado por Fco. Javier Prez Pacheco como ejercicio
# bersetzt ins Deutsche von Emiliano75rm http://programmifree.myblog.it


# importamos los mdulos necesarios
from gimpfu import *

import datetime

default_font = "Sans"

def Calendar(img, drawable, width, height, photo_porcent, month, year, font_month, size_font_month, color_month, font_number, size_font_number, color_number, color_festive, bg_weekdays, size_font_year):
	# comenzamos a agrupar el UNDO
	pdb.gimp_image_undo_group_start(img)

	old_background = pdb.gimp_context_get_background()

	pht_porcent = float(photo_porcent)/100.0

	cal_porcent = float( (100-photo_porcent) )/100.0
	
	layer_photo = drawable
	layer_photo.add_alpha()

	# SCALE IMAGE

	pdb.gimp_image_set_unit(img, UNIT_MM)
	pdb.gimp_image_set_resolution(img, 300, 300)

	w = width*118/9.99
	h = height*118/9.99

	#pdb.gimp_message(str(w) + " - " + str(h))

	pdb.gimp_image_resize(img, w, h, 0, 0)


	# CREATE BACKGROUND

	layer_bg = pdb.gimp_layer_new(img, w, h, RGB_IMAGE, "background", 100, NORMAL_MODE)
	layer_bg.add_alpha()
	img.add_layer(layer_bg, -1)
	pdb.gimp_image_lower_layer(img, layer_bg)

	pdb.gimp_context_set_background((255, 255, 255))
	layer_bg.fill(BACKGROUND_FILL)

	# SCALE PHOTO

	height_photo = h*pht_porcent - ((h*pht_porcent)/12)*2

	width_photo = (height_photo * pdb.gimp_drawable_width(drawable)) / pdb.gimp_drawable_height(drawable)

	pdb.gimp_layer_scale(layer_photo, width_photo, height_photo, True)

	layer_photo.set_offsets( (w-width_photo)/2, (h*pht_porcent)/12)

	# YEAR LAYER

	layer_year = pdb.gimp_text_fontname(img, drawable, 0, 0, str(int(year)), -1, True,  int(size_font_year), POINTS, font_month)
	pdb.gimp_layer_set_lock_alpha(layer_year, 255)
	pdb.gimp_floating_sel_to_layer(layer_year)

	pdb.gimp_layer_set_opacity(layer_year, 20)

	#pdb.gimp_layer_scale(layer_year, (w/10)*3, ( ((w/10)*3) * pdb.gimp_drawable_height(layer_year) ) / pdb.gimp_drawable_width(layer_year), True)

	x = w - layer_year.width - (w/10)
	y = h - layer_year.height - (h/25)

	layer_year.set_offsets(x, y)

	# MONTH LAYER

	months = ['', 'Januar', 'Februar', 'Mrz', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember']

	layer_month = pdb.gimp_text_fontname(img, drawable, 0, 0, months[int(month)], -1, True,  int(size_font_year), POINTS, font_month)
	pdb.gimp_layer_set_lock_alpha(layer_month, 255)
	pdb.gimp_floating_sel_to_layer(layer_month)

	pdb.gimp_layer_set_opacity(layer_month, 20)

	#pdb.gimp_layer_scale(layer_month, (w/10)*3, ( ((w/10)*3) * pdb.gimp_drawable_height(layer_month) ) / pdb.gimp_drawable_width(layer_month), True)

	x = (w/10)
	y = h - layer_month.height - (h/25)

	layer_month.set_offsets(x, y)

	# CALENDAR

	weekdays = ['Montag', 'Dienstag', 'Mittwoch', 'Donnerstag', 'Freitag', 'Samstag', 'Sonntag']

	cont = 0
	sep_w = w/9
	sep_h = (h*cal_porcent)/8

	height_layer_weekdays = 20

	while(cont<7):
		px = (cont%7)*sep_w + sep_w + (sep_w/5)
		py = (h*pht_porcent)
		layer_txt = pdb.gimp_text_fontname(img, drawable, px, py, weekdays[cont], -1, True,  int(size_font_month), POINTS, font_month)
		height_layer_weekdays = layer_txt.height
		pdb.gimp_layer_set_lock_alpha(layer_txt, 255)

		if cont==6:
			pdb.gimp_context_set_background(color_festive)
		else:
			pdb.gimp_context_set_background(color_month)

		pdb.gimp_edit_fill(layer_txt, BACKGROUND_FILL)

		pdb.gimp_floating_sel_to_layer(layer_txt)
		if cont>0:
			pdb.gimp_image_merge_down(img, layer_txt, 0)

		cont = cont + 1

	# CREATE BACKGROUND WEEKDAYS

	layer_bg_weekdays = pdb.gimp_layer_new(img, w, height_layer_weekdays+16, RGB_IMAGE, "background weekdays", 100, NORMAL_MODE)
	layer_bg_weekdays.add_alpha()
	img.add_layer(layer_bg_weekdays, -1)
	pdb.gimp_image_lower_layer(img, layer_bg_weekdays)

	pdb.gimp_context_set_background(bg_weekdays)
	layer_bg_weekdays.fill(BACKGROUND_FILL)

	layer_bg_weekdays.set_offsets(0, (h*pht_porcent)-8)

	# DAYS

	day = datetime.date(year, month, 1)
	cont = 0
	dayofmonth = datetime.date.weekday(day)

	nextmonth_year = year
	nextmonth_month = month+1
	if nextmonth_month>12:
		nextmonth_year = year+1
		nextmonth_month = 1		

	ndaysofmonth = datetime.date(nextmonth_year, nextmonth_month, 1) - day

	while(cont<ndaysofmonth.days):
		px = (dayofmonth%7)*sep_w + sep_w + (sep_w/5)
		py = (dayofmonth/7)*sep_h + (h*pht_porcent) + + sep_h
		layer_txt = pdb.gimp_text_fontname(img, drawable, px, py, str(cont+1), -1, True,  int(size_font_number), POINTS, font_number)
		pdb.gimp_layer_set_lock_alpha(layer_txt, 255)

		if dayofmonth%7==6:
			pdb.gimp_context_set_background(color_festive)
		else:
			pdb.gimp_context_set_background(color_number)

		pdb.gimp_edit_fill(layer_txt, BACKGROUND_FILL)

		pdb.gimp_floating_sel_to_layer(layer_txt)
		if cont>0:
			pdb.gimp_image_merge_down(img, layer_txt, 0)

		cont = cont + 1
		dayofmonth = dayofmonth + 1

	pdb.gimp_context_set_background(old_background)
	
	# agrupamos UNDO
	pdb.gimp_image_undo_group_end(img)

# funcin principal
if __name__ == '__main__':

	# llamada a funcin register
	register(
		"calendar",
		"Calendario",
		"Calendario",
		"Javi Pacheco",
		"Javi Pacheco",
		"2007",
		"<Image>/Python-Fu/Kalender Bilder erstellen",
		"RGB*, GRAY*",
		[
			(PF_SPINNER, "width", "Breite (mm)", 125, (0, 1000, 1)),
			(PF_SPINNER, "height", "Hhe (mm)", 142, (0, 1000, 1)),
			(PF_SPINNER, "photo_porcent", "Fotos austauschen", 60, (0, 100, 1)),
			(PF_SPINNER, "month", "Monat", 1, (1, 12, 1)),
			(PF_SPINNER, "year", "Jahr", 2008, (1900, 2999, 1)),
			(PF_FONT, "font_month", "Font Text", default_font),
			(PF_SPINNER, "size_font_month", "Manahme Monat", 30, (8, 120, 1)),
			(PF_COLOR, "color_month", "Farbe Monat", (0,0,0)),
			(PF_FONT, "font_number", "Font Zahlen", default_font),
			(PF_SPINNER, "size_font_number", "Manahme Zahlen", 50, (8, 120, 1)),
			(PF_COLOR, "color_number", "Farbe Zahlen", (0,0,0)),
			(PF_COLOR, "color_festive", "Farbe Sonntag", (0,0,0)),
			(PF_COLOR, "bg_weekdays", "Hintergrund Woche", (200,200,200)),
			(PF_SPINNER, "size_font_year", "Manahme Jahr und Monat", 120, (40, 200, 1))
		],
		[],
		Calendar)
	main()
